<?php
/*------------------------------------------
01/11/2023 Solo revision.
-----------------------------------------*/
require_once("../includes/conexion.php");
require_once("../includes/funciones.php");
// nombre del modulo al que pertenece este archivo
$modulo="1";
$submodulo="216";
require_once("../includes/rsusuario.php"); 


function limpia_valores_csv_numerico($csv){
	// Recibe el CSV
	$id_csv_array = explode(",", $csv);
	// Inicializa un nuevo arreglo para almacenar los valores limpios
	$cleaned_csv_array = array();
	// Recorre cada valor del CSV
	foreach ($id_csv_array as $id) {
		// Limpia el valor convirtiéndolo en un entero
		$cleaned_value = intval($id);
		// Agrega el valor limpio al nuevo arreglo
		$cleaned_csv_array[] = $cleaned_value;
	}
	// Vuelve a armar el CSV limpio
	$cleaned_csv = implode(",", $cleaned_csv_array);
	
	return $cleaned_csv;
}


function validar_asigna_subcuenta($parametros_array){
	global $conexion;
	global $ahora;
	global $saltolinea;
	
	
	$valido='S';
	$errores='';
	
	
	// recibe parametros
	$idventatmp_csv=limpia_valores_csv_numerico($parametros_array['idventatmp_csv']);
	$idatcdet=antisqlinyeccion($parametros_array['idatcdet'],"int");
	$idusu=antisqlinyeccion($parametros_array['idusu'],"int");
	$accion=trim($parametros_array['accion']);
	
	
	//busca si algunos de los items de idventatmp_csv tiene agregado y agrega su idventatmp al idventatmp_csv
	$consulta="
	select idventatmp 
	from tmp_ventares 
	where 
	idventatmp_princ_delagregado is not null
	and idventatmp_princ_delagregado in ($idventatmp_csv)
	";
	$rsag=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	// si hay productos con agregados
	if(intval($rsag->fields['idventatmp']) > 0){
		// Inicializa una nueva variable para almacenar los nuevos IDs
		$idventatmp_csv_new = $idventatmp_csv.',';
		// recorre si tiene agregados
		while(!$rsag->EOF){
			$idventatmp_csv_new .= $rsag->fields['idventatmp'] . ',';
		$rsag->MoveNext(); }
		// Elimina la última coma de la cadena
		$idventatmp_csv_new = rtrim($idventatmp_csv_new, ',');
		// Utiliza la nueva variable para los próximos pasos
		$idventatmp_csv = $idventatmp_csv_new;
	}
	
	// validar parametros
	if(intval($idventatmp_csv) == 0){ // si no hay ninguno sera cero por el intval asi que esta bien la comparacion
		$valido='N';
		$errores.='- No se recibio ningun producto para asignar.'.$saltolinea;
	}
	if(intval($parametros_array['idatcdet']) <= 0){
		$valido='N';
		$errores.='- No se recibio a que subcuenta asignar.'.$saltolinea;
	}
	if(intval($parametros_array['idusu']) <= 0){
		$valido='N';
		$errores.='- No se recibio el usuario a asignar.'.$saltolinea;
	}
	if(trim($parametros_array['accion']) != 'ASIGNA' && trim($parametros_array['accion']) != 'DESASIGNA'){
		$valido='N';
		$errores.='- No se recibio la accion a ejecutar.'.$saltolinea;
	}

	
	// validar que tenga permisos para separar cuenta
	$consulta="
	select permite_separacuenta from mesas_preferencias limit 1
	";
	$rspref=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	$permite_separacuenta=$rspref->fields['permite_separacuenta'];
	if($permite_separacuenta != 'S'){
		$valido='N';
		$errores.='- La opcion de separar cuentas fue desactivada por la administracion.'.$saltolinea;
	}
	
	
	// busca el idatcdet a asignar a que idatc corresponde
	$consulta="
	select idatc from mesas_atc_det where idatcdet = $idatcdet
	";
	$rs=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	$idatc=intval($rs->fields['idatc']);
	
	// busca si el idatc a asignar es valido y esta activo
	$consulta="
	select idatc from mesas_atc where idatc = $idatc and estado = 1
	";
	$rs=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	$idatc_act=intval($rs->fields['idatc']);
	if($idatc_act <= 0){
		$valido='N';
		$errores.='- El atc '.$idatc.' de tu mesa ya no se encuentra activo.'.$saltolinea;
	}
	
	// busca si hay items que no corresponden al mismo atc
	$consulta="
	select count(*) as total 
	from 
	(
		SELECT tmp_ventares_cab.idatc 
		FROM `tmp_ventares`
		inner join tmp_ventares_cab on tmp_ventares_cab.idtmpventares_cab = tmp_ventares.idtmpventares_cab
		where
		tmp_ventares.idventatmp in ( $idventatmp_csv )
		group by tmp_ventares_cab.idatc
	) atc_s
	";
	$rs=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	$totalregistros=intval($rs->fields['total']);
	if($totalregistros <= 0){
		$valido='N';
		$errores.='- No se pudo asignar por que no se encontro ningun item.'.$saltolinea;
	}
	if($totalregistros > 1){
		$valido='N';
		$errores.='- No se pudo asignar por que se encontraron items que no corresponden al mismo atc.'.$saltolinea;
	}
	

	

	
	
	$res=array(
		'valido' => $valido,
		'errores' => $errores
	);
	
	
	return $res;
	
	
}

function registrar_asigna_subcuenta($parametros_array){
	global $conexion;
	global $ahora;
	global $saltolinea;

	
	// recibe parametros
	$idventatmp_csv=limpia_valores_csv_numerico($parametros_array['idventatmp_csv']);
	$idatcdet=antisqlinyeccion($parametros_array['idatcdet'],"int");
	$idusu=antisqlinyeccion($parametros_array['idusu'],"int");
	$accion=trim($parametros_array['accion']);
	
	
	
	//busca si algunos de los items de idventatmp_csv tiene agregado y agrega su idventatmp al idventatmp_csv
	$consulta="
	select idventatmp 
	from tmp_ventares 
	where 
	idventatmp_princ_delagregado is not null
	and idventatmp_princ_delagregado in ($idventatmp_csv)
	";
	$rsag=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	// si hay productos con agregados
	if(intval($rsag->fields['idventatmp']) > 0){
		// Inicializa una nueva variable para almacenar los nuevos IDs
		$idventatmp_csv_new = $idventatmp_csv.',';
		// recorre si tiene agregados
		while(!$rsag->EOF){
			$idventatmp_csv_new .= $rsag->fields['idventatmp'] . ',';
		$rsag->MoveNext(); }
		// Elimina la última coma de la cadena
		$idventatmp_csv_new = rtrim($idventatmp_csv_new, ',');
		// Utiliza la nueva variable para los próximos pasos
		$idventatmp_csv = $idventatmp_csv_new;
	}
	//echo 'a:'.$idventatmp_csv;exit;

	// busca el atc por seguridad
	$consulta="
	select idatc from mesas_atc_det where idatcdet = $idatcdet
	";
	$rs=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	$idatc=intval($rs->fields['idatc']);
	
	// busca todos los idventatmp y por seguridad valida por atc
	$consulta="
	select idventatmp, idatcdet
	from tmp_ventares
	where
	idtmpventares_cab in (select idtmpventares_cab from tmp_ventares_cab where idatc = $idatc)
	and idventatmp in ($idventatmp_csv)
	";
	$rs=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	
	
	// cabecera del log para ver la tanda
	$consulta="
	insert into mesas_atc_det_asigna_cab_log
	(registrado_por,registrado_el)
	values
	($idusu,'$ahora')
	";
	$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	$consulta="
	select idatcdetasignacablog from mesas_atc_det_asigna_cab_log where registrado_por = $idusu order by idatcdetasignacablog desc limit 1
	";
	$rslog=$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
	$idatcdetasignacablog=$rslog->fields['idatcdetasignacablog'];
	
	// recorre cada registro y asigna
	while(!$rs->EOF){
		$idventatmp=intval($rs->fields['idventatmp']);
		$idatcdet_ant=antisqlinyeccion($rs->fields['idatcdet'],"int");
		if($accion == 'DESASIGNA'){
			$idatcdet_new="NULL";
		}else{
			$idatcdet_new=$idatcdet;
		}
		
		// registra en el log
		$consulta="
		insert into mesas_atc_det_asigna_log
		(idatcdetasignacablog,idventatmp,idatcdet_ant,idatcdet_new,registrado_por,registrado_el)
		values
		($idatcdetasignacablog,$idventatmp,$idatcdet_ant,$idatcdet_new,$idusu,'$ahora')
		";
		$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
		
		// cambia la asignacion
		$consulta="
		update tmp_ventares
		set
		idatcdet = $idatcdet_new
		where
		idventatmp = $idventatmp
		";
		$conexion->Execute($consulta) or die(errorpg($conexion,$consulta));
		
	$rs->MoveNext(); }
	
	$res=array(
		'idatcdetasignacablog' => $idatcdetasignacablog
	);
	
	
	return $res;
}


$valido='S';
$errores='';

$parametros_array=array(
	'idusu' => $idusu,
	'idatcdet' => $_POST['idatcdet'],
	'idventatmp_csv' => $_POST['idventatmp_csv'],
	'accion' => $_POST['accion'],
);
$res=validar_asigna_subcuenta($parametros_array);
if($res['valido'] != 'S'){
	$valido=$res['valido'];
	$errores.=$res['errores'];
}
// si todo es valido
if($res['valido'] == 'S'){
	$res=registrar_asigna_subcuenta($parametros_array);
	$idatcdetasignacablog=$res['idatcdetasignacablog'];
}


// genera array con los datos
$arr = array(
	'valido' => $valido,
	'errores' => $errores,
	'idatcdetasignacablog' => $idatcdetasignacablog
);

//print_r($arr);

// convierte a formato json
$respuesta=json_encode($arr, JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT | JSON_HEX_AMP | JSON_UNESCAPED_UNICODE);

// devuelve la respuesta formateada
echo $respuesta;
exit;


?>