<?php
/*


DROP TRIGGER IF EXISTS `{[BASE]}`.`bloquear_borrado_sucursal`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`bloquear_borrado_sucursal` BEFORE UPDATE ON `sucursales`
 FOR EACH ROW BEGIN
    IF NEW.estado = 6 AND NEW.borrado_por IS NULL THEN
        SIGNAL SQLSTATE '45000'
        SET MESSAGE_TEXT = 'No se puede borrar esta sucursal por que no asignaste todos los parametros obligatorios.';
    END IF;
END
$$
DELIMITER ;


DROP TRIGGER IF EXISTS `{[BASE]}`.`ventas_before_insert`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`ventas_before_insert` BEFORE INSERT ON `ventas`
 FOR EACH ROW BEGIN
    IF EXISTS( SELECT 1 FROM ventas WHERE factura = NEW.factura and timbrado = NEW.timbrado AND estado <> 6) THEN
        signal SQLSTATE '45000' SET MESSAGE_TEXT = 'Factura duplicada para el timbrado seleccionado'; 
    END IF;
    IF EXISTS( SELECT 1 FROM ventas WHERE idventa = NEW.idventa ) THEN
        signal SQLSTATE '45000' SET MESSAGE_TEXT = 'Idventa duplicado'; 
    END IF;
END
$$
DELIMITER ;


DROP TRIGGER IF EXISTS `{[BASE]}`.`cliente_before_insert`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`cliente_before_insert` BEFORE INSERT ON `cliente`
 FOR EACH ROW BEGIN
    IF LENGTH(TRIM(NEW.razon_social)) < 4 THEN
        SIGNAL SQLSTATE '45000' SET MESSAGE_TEXT = 'La razón social debe tener al menos 4 caracteres';
    END IF;
END
$$
DELIMITER ;



DROP TRIGGER IF EXISTS `{[BASE]}`.`cliente_before_update`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`cliente_before_update` BEFORE UPDATE ON `cliente`
 FOR EACH ROW BEGIN
           IF NEW.estado = 6 AND OLD.borrable = 'N'  THEN
               SET NEW.estado = 1;
           END IF;
			IF LENGTH(TRIM(NEW.razon_social)) < 4 THEN
				SIGNAL SQLSTATE '45000' SET MESSAGE_TEXT = 'La razón social debe tener al menos 4 caracteres';
			END IF;
END
$$
DELIMITER ;


DROP TRIGGER IF EXISTS `{[BASE]}`.`before_insert_montocabonado`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`before_insert_montocabonado` BEFORE INSERT ON `mesas_cobros_deta`
 FOR EACH ROW BEGIN
    IF NEW.montoabonado < 0 THEN
        SIGNAL SQLSTATE '45000'
        SET MESSAGE_TEXT = 'No se permiten valores negativos en montoabonado';
    END IF;
END
$$
DELIMITER ;

DROP TRIGGER IF EXISTS `{[BASE]}`.`before_update_montocabonado`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`before_update_montocabonado` BEFORE UPDATE ON `mesas_cobros_deta`
 FOR EACH ROW BEGIN
    IF NEW.montoabonado < 0 THEN
        SIGNAL SQLSTATE '45000'
        SET MESSAGE_TEXT = 'No se permiten valores negativos en montoabonado';
    END IF;
END
$$
DELIMITER ;



DROP TRIGGER IF EXISTS `{[BASE]}`.`verificar_stock_antes_insertar`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`verificar_stock_antes_insertar` BEFORE INSERT ON `ventas_detalles` FOR EACH ROW BEGIN
    DECLARE disponible_actual INT DEFAULT 0;
    DECLARE ventas_nostock_col INT DEFAULT 0;
    DECLARE error_message VARCHAR(255);
    DECLARE hab_invent_col INT DEFAULT 0;
	DECLARE idinsumo_col INT DEFAULT 0;

    -- Obtener el valor de ventas_nostock de la tabla preferencias
    SELECT ventas_nostock INTO ventas_nostock_col
    FROM preferencias
    LIMIT 1;

    -- Obtener el valor de hab_invent para el producto
	SELECT hab_invent, idinsumo INTO hab_invent_col, idinsumo_col
    FROM insumos_lista
    WHERE idproducto = NEW.idprod
    LIMIT 1;
	
	

    -- Continuar solo si hab_invent es igual a 1
    IF hab_invent_col = 1 THEN
        -- Validar si ventas_nostock es igual a 2
        IF ventas_nostock_col = 2 THEN
            -- Buscar la cantidad disponible en gest_depositos_stock_gral
            SELECT COALESCE(disponible, 0) INTO disponible_actual
            FROM gest_depositos_stock_gral
            WHERE 
                idproducto = idinsumo_col
                AND iddeposito = NEW.iddeposito_det
            LIMIT 1;

            -- Bloquear la inserción si la cantidad disponible es menor que la cantidad deseada
            IF disponible_actual < NEW.cantidad THEN               
				SET error_message = CONCAT('Stock insuficiente del producto A: ', idinsumo_col, ' P: ', NEW.idprod, ' en el deposito especificado: [', NEW.iddeposito_det,'], hay ', disponible_actual, ' y usted quiere insertar ', NEW.cantidad);
                SIGNAL SQLSTATE '45000'
                SET MESSAGE_TEXT = error_message;
            END IF;
        END IF;
    END IF;
END
$$
DELIMITER ;


DROP TRIGGER IF EXISTS `{[BASE]}`.`before_insert_ventas_rendido`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`before_insert_ventas_rendido` BEFORE INSERT ON `ventas_rendido` FOR EACH ROW BEGIN
    IF NEW.estado = 1 THEN
        IF EXISTS (SELECT 1 FROM ventas_rendido WHERE idventa = NEW.idventa AND estado = 1) THEN
            SIGNAL SQLSTATE '45000'
            SET MESSAGE_TEXT = 'idventa duplicado con estado 1 no permitido';
        END IF;
    END IF;
END
$$
DELIMITER ;
COMMIT;


DROP TRIGGER IF EXISTS `{[BASE]}`.`trg_before_insert_productos`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`trg_before_insert_productos` BEFORE INSERT ON `productos` FOR EACH ROW BEGIN
    DECLARE pref_repite_codigo_barra CHAR(1);
    DECLARE id_producto INT;
    DECLARE nombre_producto VARCHAR(255);
    
    -- Obtiene el valor de repite_codigo_barra de la tabla preferencias
    SELECT repite_codigo_barra INTO pref_repite_codigo_barra FROM preferencias LIMIT 1;

    -- Solo realizar la verificación si pref_repite_codigo_barra es 'N' y el nuevo barcode no es NULL
    IF pref_repite_codigo_barra = 'N' AND NEW.barcode IS NOT NULL THEN
        -- Verifica si existe otro producto con el mismo barcode y borrado = 'N'
        SELECT idprod_serial, descripcion INTO id_producto, nombre_producto
        FROM productos
        WHERE barcode = NEW.barcode AND borrado = 'N'
        LIMIT 1;

        -- Si se encontró un producto con el mismo barcode, generar un error
        IF id_producto IS NOT NULL THEN
            SET @msg = CONCAT('Error: El código de barras ', NEW.barcode, ' ya existe para otro producto no borrado. ID del producto: ', id_producto, ', Nombre del producto: ', nombre_producto);
            SIGNAL SQLSTATE '45000' SET MESSAGE_TEXT = @msg;
        END IF;
    END IF;
END
$$

DELIMITER ;
DROP TRIGGER IF EXISTS `{[BASE]}`.`trg_before_update_productos`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`trg_before_update_productos` BEFORE UPDATE ON `productos` FOR EACH ROW BEGIN
    DECLARE pref_repite_codigo_barra CHAR(1);
    DECLARE id_producto INT;
    DECLARE nombre_producto VARCHAR(255);
	DECLARE accion CHAR(1);
	DECLARE usuario_registrado INT;
    
    -- Obtiene el valor de repite_codigo_barra de la tabla preferencias
    SELECT repite_codigo_barra INTO pref_repite_codigo_barra FROM preferencias LIMIT 1;

    -- Solo realizar la verificación si pref_repite_codigo_barra es 'N' y el nuevo barcode no es NULL
    IF pref_repite_codigo_barra = 'N' AND NEW.barcode IS NOT NULL THEN
        -- Verifica si existe otro producto con el mismo barcode y borrado = 'N' y diferente id
        SELECT idprod_serial, descripcion INTO id_producto, nombre_producto
        FROM productos
        WHERE barcode = NEW.barcode AND borrado = 'N'
          AND idprod_serial != OLD.idprod_serial
        LIMIT 1;

        -- Si se encontró un producto con el mismo barcode, generar un error
        IF id_producto IS NOT NULL THEN
            SET @msg = CONCAT('Error: El código de barras ', NEW.barcode, ' ya existe para otro producto no borrado. ID del producto: ', id_producto, ', Nombre del producto: ', nombre_producto);
            SIGNAL SQLSTATE '45000' SET MESSAGE_TEXT = @msg;
        END IF;
    END IF;
	
	-- Verificar si la columna 'borrado' ha cambiado
    IF OLD.borrado != NEW.borrado THEN
        

        -- Determinar la acción a registrar
        IF NEW.borrado = 'S' THEN
            SET accion = 'B'; -- Borrar
			SET usuario_registrado = NEW.borrado_por;
        ELSEIF NEW.borrado = 'N' THEN
            SET accion = 'R'; -- Restaurar
			SET usuario_registrado = NEW.restaurado_por;
        END IF;

        -- Insertar el log en la tabla productos_bor_res_log
        INSERT INTO productos_bor_res_log (accion, registrado_por, registrado_el, idproducto)
        VALUES (accion, usuario_registrado, NOW(), NEW.idprod_serial);
    END IF;
	
	
END
$$
DELIMITER ;
COMMIT;


DELIMITER ;
DROP TRIGGER IF EXISTS `{[BASE]}`.`trg_before_update_insumos_lista`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`trg_before_update_insumos_lista` BEFORE UPDATE ON `insumos_lista` FOR EACH ROW BEGIN
    DECLARE accion CHAR(1);
    DECLARE usuario_registrado VARCHAR(255);
    
    -- Verificar si la columna 'estado' ha cambiado
    IF OLD.estado != NEW.estado THEN
        -- Determinar la acción a registrar
        IF NEW.estado = 'I' THEN
            SET accion = 'B'; -- Inactivo (equivalente a Borrado)
            SET usuario_registrado = NEW.borrado_por;
        ELSEIF NEW.estado = 'A' THEN
            SET accion = 'R'; -- Activo (equivalente a Restaurado)
            SET usuario_registrado = NEW.restaurado_por;
        END IF;

        -- Insertar el log en la tabla insumos_lista_bor_res_log
        INSERT INTO insumos_lista_bor_res_log (accion, registrado_por, registrado_el, idinsumo)
        VALUES (accion, usuario_registrado, NOW(), NEW.idinsumo);
    END IF;

END
$$
DELIMITER ;
COMMIT;



DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`after_update_documentos_electronicos_emitidos`
AFTER UPDATE ON `documentos_electronicos_emitidos`
FOR EACH ROW
BEGIN
    -- Solo proceder si el nuevo valor de estado_set es 3
    IF NEW.estado_set = 3 THEN
        
        -- Caso 1: Si idventa > 0
        IF NEW.idventa > 0 THEN


            DELETE FROM `documentos_electronicos_log`
            WHERE idventa = NEW.idventa
              AND idservicio <= 4;
        END IF;

        -- Caso 2: Si idnotacredito > 0
        IF NEW.idnotacredito > 0 THEN


            DELETE FROM `documentos_electronicos_log`
            WHERE idnotacredito = NEW.idnotacredito
              AND idservicio <= 4;
        END IF;

        -- Caso 3: Si idnotadebito > 0
        IF NEW.idnotadebito > 0 THEN


            DELETE FROM `documentos_electronicos_log`
            WHERE idnotadebito = NEW.idnotadebito
              AND idservicio <= 4;
        END IF;

        -- Caso 4: Si idnotaremision > 0
        IF NEW.idnotaremision > 0 THEN


            DELETE FROM `documentos_electronicos_log`
            WHERE idnotaremision = NEW.idnotaremision
              AND idservicio <= 4;
        END IF;

        -- Caso 5: Si idautofactura > 0
        IF NEW.idautofactura > 0 THEN


            DELETE FROM `documentos_electronicos_log`
            WHERE idautofactura = NEW.idautofactura
              AND idservicio <= 4;
        END IF;

    END IF;
END$$
DELIMITER ;








DELIMITER ;

DROP TRIGGER IF EXISTS `{[BASE]}`.`prevent_negative_discount_update`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`prevent_negative_discount_update` 
BEFORE INSERT ON `ventas_detalles`
FOR EACH ROW BEGIN

    IF NEW.descuento < 0 THEN
        SIGNAL SQLSTATE '45000'
        SET MESSAGE_TEXT = 'No se permite actualizar un registro con descuento negativo.';
    END IF;

END
$$
DELIMITER ;

DROP TRIGGER IF EXISTS `{[BASE]}`.`prevent_negative_discount_insert`;
DELIMITER $$
CREATE TRIGGER `{[BASE]}`.`prevent_negative_discount_insert` 
BEFORE INSERT ON `ventas_detalles`
FOR EACH ROW BEGIN

    IF NEW.descuento < 0 THEN
        SIGNAL SQLSTATE '45000'
        SET MESSAGE_TEXT = 'No se permite insertar un registro con descuento negativo.';
    END IF;

END
$$
DELIMITER ;


*/
?>