<?php
require_once("../includes/conexion.php");
require_once("../includes/funciones.php");

header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');
header('Content-Type: application/json');

class well_acceso_molinete
{

    private $nroDocumento;
    private $jsonRespuesta;
    private $idCliente;
    private $totalClientes;

    public function iniciar($nroDocumento)
    {

        // Setea el valor de la cedula
        $this->nroDocumento = $nroDocumento;
        # 1: Verifica existencia de usuario
        $this->verificaExistenciaUsuario();
        # 3: Verifica si el cliente tiene permitido acceder
        $this->verificaAccesoMoliniteCliente();
        # 4: Imprime la respuesta
        $this->generaRespuesta();
    }

    private function verificaExistenciaUsuario()
    {

        global $conexion;
        $nroDocumento = antisqlinyeccion($this->nroDocumento, 'text');

        $cliente = "SELECT idcliente FROM cliente WHERE documento = $nroDocumento";
        $rscliente = $conexion->Execute($cliente) or die(errorpg($conexion, $cliente));

        $this->idCliente = $rscliente->fields['idcliente'];
        $this->totalClientes = $rscliente->recordCount();
    }

    private function verificaAccesoMoliniteCliente()
    {

        global $conexion;
        global $ahora;
        $nroDocumento = antisqlinyeccion($this->nroDocumento, 'text');

        $hoy = date("Y-m-d");
        $ahora = date("Y-m-d H:i:s");
        $ERROR_string = '';
        $message = '';

        if ($this->nroDocumento) {
            // Si es cliente con membresia
            if ($this->totalClientes == 0) {

                $jsonRespuesta = array(
                    'status' => false,
                    'msg' => "No se obtuvo ningun usuario con el documento: $nroDocumento",
                );

                $this->jsonRespuesta = json_encode($jsonRespuesta);
            } else {

                $consulta = "SELECT 
                            cliente.idcliente, 
                            saldo_mensual, 
                            bloqueado_sistema, 
                            bloqueo_auto_dias_ultpag, 
                            nombre,
                            apellido,
                            idmembresia, 
                            valido_hasta,
                            disponible_dias,
                            cliente.documento,
                            cuentas_clientes_membresia.idtipocuenta,
                            (SELECT COUNT(*) FROM registros_asistencias WHERE idcliente=cliente.idcliente AND estado<>6) as cantidad_asiste
                        FROM 
                            cliente 
                        INNER JOIN 
                            cuentas_clientes_membresia ON cuentas_clientes_membresia.idcliente=cliente.idcliente
                        WHERE 
                            cliente.documento = $nroDocumento";
                $rs = $conexion->Execute($consulta) or die(errorpg($conexion, $consulta));
                $total_registros = $rs->RecordCount();

                $fecha_valido = trim($rs->fields['valido_hasta']);
                $formateado = date("d/m/Y", strtotime($fecha_valido));
                $cliente = trim($rs->fields['nombre']) . ' ' . ($rs->fields['apellido']);
                $idCliente = antisqlinyeccion($this->idCliente, "int");
                $idmembresia = intval($rs->fields['idmembresia']);
                $idtipocuenta = intval($rs->fields['idtipocuenta']);

                if ($total_registros == 0) {

                    $ERROR_string .= " No se encuentra el cliente o la membresia se encuentra inactiva";
                    $jsonRespuesta = array(
                        'status' => false,
                        'msg' => $ERROR_string,
                    );

                    $this->jsonRespuesta = json_encode($jsonRespuesta);
                } elseif ($fecha_valido == '' && $idtipocuenta != 7) {

                    $ERROR_string .= "Membresia de $cliente, no posee vencimiento. Establezca y vuelva a intentar.";

                    $jsonRespuesta = array(
                        'status' => false,
                        'msg' => $ERROR_string,
                    );

                    $this->jsonRespuesta = json_encode($jsonRespuesta);
                } elseif ($hoy >= $fecha_valido && $idtipocuenta != 7) {

                    $ERROR_string .= "Querido/a cliente " . $cliente .  " usted cuenta con su membresia vencida desde el dia $formateado";

                    $jsonRespuesta = array(
                        'status' => false,
                        'msg' => $ERROR_string,
                    );
                    $this->jsonRespuesta = json_encode($jsonRespuesta);
                } else {

                    if ($fecha_valido == '' && $idtipocuenta == 7) {

                        $msg = 'Ingreso correcto, bienvenido/a ' . $cliente;

                        $jsonRespuesta = array(
                            'status' => true,
                            'msg' => $msg,
                        );
                        $this->jsonRespuesta = json_encode($jsonRespuesta);
                    }

                    if ($hoy < $fecha_valido) {

                        // Genera respuesta
                        $msg = 'Ingreso correcto, bienvenido/a ' . $cliente . ' su fecha de vencimiento es el ' . $formateado;

                        $jsonRespuesta = array(
                            'status' => true,
                            'msg' => $msg,
                        );
                        $this->jsonRespuesta = json_encode($jsonRespuesta);
                    }

                    $insertar = "Insert into registros_asistencias
                        (idcliente,idmembresia,fecha_asistencia,registrado_por,estado,observaciones)
                            values
                        ($idCliente,$idmembresia,'$ahora',0,1,NULL)";
                    $conexion->Execute($insertar) or die(errorpg($conexion, $insertar));
                }if ($total_registros == 0) {

                    $ERROR_string .= " No se encuentra el cliente o la membresia se encuentra inactiva";
                    $jsonRespuesta = array(
                        'status' => false,
                        'msg' => $ERROR_string,
                    );

                    $this->jsonRespuesta = json_encode($jsonRespuesta);
                } elseif ($fecha_valido == '' && $idtipocuenta != 7) {

                    $ERROR_string .= "Membresia de $cliente, no posee vencimiento. Establezca y vuelva a intentar.";

                    $jsonRespuesta = array(
                        'status' => false,
                        'msg' => $ERROR_string,
                    );

                    $this->jsonRespuesta = json_encode($jsonRespuesta);
                } elseif ($hoy >= $fecha_valido && $idtipocuenta != 7) {

                    $ERROR_string .= "Querido/a cliente " . $cliente .  " usted cuenta con su membresia vencida desde el dia $formateado";

                    $jsonRespuesta = array(
                        'status' => false,
                        'msg' => $ERROR_string,
                    );
                    $this->jsonRespuesta = json_encode($jsonRespuesta);
                } else {

                    if ($fecha_valido == '' && $idtipocuenta == 7) {

                        $msg = 'Ingreso correcto, bienvenido/a ' . $cliente;

                        $jsonRespuesta = array(
                            'status' => true,
                            'msg' => $msg,
                        );
                        $this->jsonRespuesta = json_encode($jsonRespuesta);
                    }

                    if ($hoy < $fecha_valido) {

                        // Genera respuesta
                        $msg = 'Ingreso correcto, bienvenido/a ' . $cliente . ' su fecha de vencimiento es el ' . $formateado;

                        $jsonRespuesta = array(
                            'status' => true,
                            'msg' => $msg,
                        );
                        $this->jsonRespuesta = json_encode($jsonRespuesta);
                    }

                    $insertar = "Insert into registros_asistencias
                        (idcliente,idmembresia,fecha_asistencia,registrado_por,estado,observaciones)
                            values
                        ($idCliente,$idmembresia,'$ahora',0,1,NULL)";
                    $conexion->Execute($insertar) or die(errorpg($conexion, $insertar));
                }
            }
        }
    }

    private function generaRespuesta()
    {

        print_r($this->jsonRespuesta);
    }
}

$authorizationHeader = isset($_SERVER['HTTP_AUTHORIZATION']) ? $_SERVER['HTTP_AUTHORIZATION'] : null;
$token = null;

if ($authorizationHeader && strpos($authorizationHeader, 'Bearer ') === 0) {
    $token = substr($authorizationHeader, 7); // Extract the token
}

if ($token == '93bdf063c1142f52631e2d04393a3a3da2f40ad73244c17e825188242040b7f6b04b2e6c6309ed5627d7e323a935caf24f2935ba56893f7bf8b795ec4617bb05') {

    /* get json data and process to decodificate*/
    $data = json_decode(file_get_contents('php://input'));
    $OBJ_obtiene_ingresos_usuarios = new well_acceso_molinete();
    $rsp = $OBJ_obtiene_ingresos_usuarios->iniciar($data->cedula);
} else {

    $jsonRespuestaCabecera = array(
        'status' => False,
        'msg' => 'Error de conectividad',
    );

    print_r(json_encode($jsonRespuestaCabecera));
}
